@@ -72,4 +72,11 @@ class XIVAPIError(Exception):
     """
     XIVAPI error
     """
-    pass
\ No newline at end of file
+    pass
+
+
+class XIVAPIInvalidAlgo(Exception):
+    """
+    Invalid String Algo
+    """
+    pass
